module HROOT.Graf.TArc
       (TArc(..), ITArc, upcastTArc, downcastTArc, newTArc) where
import HROOT.Graf.TArc.RawType
import HROOT.Graf.TArc.Interface
import HROOT.Graf.TArc.Implementation
